<?php
#G
#=
//ce tableau est utilisé pour le backup et le restore qui sont des algorithmes
//guidés par son contenu (celui du tableau !).
//Les valeurs de l'indice de la première dimension du tableau sont les tables
//qu'il faut sauver ou restaurer.
//Les tables qui n'y sont pas sont des tables de constantes :
//  _params_globaux, disc_gep, disciplines, types_auth.

//Pour ces tables :
// - 'cle' est la clé primaire autonumber lorsqu'elle existe
// - 'garder' signifie qu'il faudra garder dans un tableau la correspondance
//    entre ancienne et nouvelle clé primaire (le nouvel autonumber).
// - 'etab' indique si etab_id est une clé étrangère de la table
// - 'passe1' clés étrangères qui se résolvent en passe 1
// - 'passe2  clés étrangères qui se résolvent en passe 2
// - 'liens' indique les valeurs à stocker négativement dans le backup ou à
//    convertitr immédiatement lorsque c'est possible.

/*
Donc, en plus de stocker chaque enregistrement il faut prendre 2 décisions :
1) Si on ne connaît pas encore la véritable valeur d'une clé étrangère, il faut
        la stocker négativement dans la base et la traiter en passe 2. Sinon, il
        faut la convertir et stocker sa nouvelle valeur en utilisant le tableau de
        conversion (voir 2))
2) Certaines clés primaires qui sont utilisées en clés étrangères dans d'autres
        tables doivent être stokées pour être utilisées en passe 1 si c'est possible
        (3e partie), en passe 2 sinon (2e partie).


*/

$guide=array(
//cas un peu particulier pour l'algorithme, mais il faut bien la stocker !
    'etablissements' => array('cle'    => 'etab_id',
                       'garder' => false,
                       'etab'   => false,
                       'passe1' => array(),
                       'passe2' => array()),

//2 tables faciles à stocker.
//classes doit être stockée au début pour la clé étrangère de 'eleves'
    'classes' => array('cle'    => 'classe_id',
                       'garder' => true,
                       'etab'   => true,
                       'passe1' => array(),
                       'passe2' => array()),
    'libelles_perso' => array('cle'    => '',
                       'garder' => false,
                       'etab'   => true,
                       'passe1' => array(),
                       'passe2' => array()),

//2 tables stockées telles quelles, avec des valeurs négatives pour les clés étrangères
//Ce sont les seules nécessitant une passe 2
    'eleves'  => array('cle'    => 'eleve_id',
                       'garder' => true ,
                       'etab'   => true,
                       'passe1' => array('classe_id'),
                       'passe2' => array('compte_id')),
    'profs'   => array('cle'    => 'prof_id',
                       'garder' => true ,
                       'etab'   => true,
                       'passe1' => array(),
                       'passe2' => array('compte_id')),

//pour ces tables, les nouvelles valeurs des clés étrangères sont toutes connues
//(demandes permet de connaître juste avant une clé étrangère pour reponses)
    'comptes' => array('cle'    => 'compte_id',
                       'garder' => true ,                     //pour la passe 2
                       'etab'   => true,
                       'passe1' => array('prof_id','eleve_id'),
                       'passe2' => array()),
    'demandes'=> array('cle'    => 'message_id',
                       'garder' => true ,                     //pour la passe 1
                       'etab'   => false,
                       'passe1' => array('eleve_id'),
                       'passe2' => array()),
    'reponses'=> array('cle'    => 'reponse_id',
                       'garder' => false,
                       'etab'   => false,
                       'passe1' => array('message_id','prof_id'),
                       'passe2' => array()),
    'resultats'  => array('cle'    => 'resultat_id',
                       'garder' => false,
                       'etab'   => false,
                       'passe1' => array('eleve_id'),
                       'passe2' => array()),
    'lpi'  => array('cle'    => '',
                       'garder' => false,
                       'etab'   => false,
                       'passe1' => array('prof_id'),
                       'passe2' => array()),
    'lien_profs_classes'  => array('cle'    => '',
                       'garder' => false,
                       'etab'   => false,
                       'passe1' => array('prof_id','classe_id'),
                       'passe2' => array()),
    'lien_eleves_disciplines'  => array('cle'    => '',
                       'garder' => false,
                       'etab'   => false,
                       'passe1' => array('eleve_id'),
                       'passe2' => array()),
    'lien_eleves_classes'  => array('cle'    => '',
                       'garder' => false,
                       'etab'   => false,
                       'passe1' => array('eleve_id','classe_id'),
                       'passe2' => array()),

    '_params_auth'  => array('cle'    => 'param_id',
                       'garder' => false,
                       'etab'   => true,
                       'passe1' => array(),
                       'passe2' => array()),

    'changements_logins'  => array('cle'    => '',
                       'garder' => false,
                       'etab'   => true,
                       'passe1' => array(),
                       'passe2' => array()),
    'erreurs_logins' => array('cle'    => 'erid',
                       'garder' => false,
                       'etab'   => true,
                       'passe1' => array('compte_id'),
                       'passe2' => array()),
    'brevets'  		=> array('cle'	=> 'bid',
    		  		   'garder' => false,
    		  		   'etab'	=> false,
    		  		   'passe1' => array('eleve_id'),
    		  		   'passe2' => array()),
    'divers'   		=> array('cle'	=> 'divers_id',	
    				   'garder'	=> false,
					   'etab'	=> true,
					   'passe1' => array(),
					   'passe2' => array())
	/* à FAIRE !
	'averts'		=> array('cle'	=> 'avert_id',
						'garder' => false,
						'etab'	=> 
	'textes'		=> 
	*/
    );

?>